clp\_ffi\_py package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   clp_ffi_py.ir

Submodules
----------

.. toctree::
   :maxdepth: 4

   clp_ffi_py.utils
   clp_ffi_py.wildcard_query

Module contents
---------------

.. automodule:: clp_ffi_py
   :members:
   :undoc-members:
   :show-inheritance:
